@@ -1,8 +1,7 @@
 package File::Find::Object::PathComp;
-$File::Find::Object::PathComp::VERSION = '0.3.8';
+$File::Find::Object::PathComp::VERSION = '0.3.9';
 use strict;
 use warnings;
-
 use integer;
 
 use parent 'File::Find::Object::Base';
@@ -26,7 +25,7 @@ use Class::XSAccessor accessors => {
     setters => { _set_inodes => '_inodes' },
     ;
 
-use File::Spec;
+use File::Spec ();
 
 __PACKAGE__->_make_copy_methods(
     [
@@ -146,7 +145,7 @@ File::Find::Object::PathComp - base class for File::Find::Object's Path Componen
 
 =head1 VERSION
 
-version 0.3.8
+version 0.3.9
 
 =head1 DESCRIPTION
 
